@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_PARAMETERS_H
@@ -9,16 +9,16 @@
 
 #include <QString>
 
+#ifdef C2B_USE_QMAKE
+const QString C2B_DATA_DIR("/usr/share/cb2bib");
+#else
+#include "cb2bib_conf_parameters.h"
+#endif
+
 const int C2B_MESSAGE_TIME(6000);
 const QString C2B_APPLICATION("cb2Bib");
 const QString C2B_CITE_ID_PATTERN("<<author_first>><<year_abbreviated>><<ppages_first>>");
 const QString C2B_DOCUMENT_ID_PATTERN("<<citeid>>");
-#ifdef Q_WS_X11
-const QString C2B_DATA_DIR("/usr/share/cb2bib");
-#endif
-#ifdef Q_WS_MACX
-const QString C2B_DATA_DIR("Contents/Resources");
-#endif
 const QString C2B_FIND_REPLACE_LIST(
     "Corresponding Author Contact Information||ScienceDirect alt tag^e"
     "E-mail The Corresponding Author||ScienceDirect alt tag^e"
@@ -33,7 +33,7 @@ const QString C2B_ICON_DISCONNECT_B("connect_no.png");
 const QString C2B_ICON_VIEWBIB_B("viewbib.png");
 const QString C2B_ICON_VIEWC2B_B("viewcb.png");
 const QString C2B_ORGANIZATION("MOLspaces");
-const QString C2B_VERSION("1.4.1");
+const QString C2B_VERSION("1.4.4");
 
 // File Manager Client
 #ifdef Q_WS_X11
@@ -43,10 +43,10 @@ const QString C2B_FM_CLIENT_MOVE_ARG("move");
 const QString C2B_FM_CLIENT_MOVE_BIN("kfmclient");
 #endif
 #ifdef Q_WS_MACX
-const QString C2B_FM_CLIENT_COPY_ARG("copy");
-const QString C2B_FM_CLIENT_COPY_BIN("kfmclient");
-const QString C2B_FM_CLIENT_MOVE_ARG("move");
-const QString C2B_FM_CLIENT_MOVE_BIN("kfmclient");
+const QString C2B_FM_CLIENT_COPY_ARG("");
+const QString C2B_FM_CLIENT_COPY_BIN("");
+const QString C2B_FM_CLIENT_MOVE_ARG("");
+const QString C2B_FM_CLIENT_MOVE_BIN("");
 #endif
 #ifdef Q_WS_WIN
 const QString C2B_FM_CLIENT_COPY_ARG("");
@@ -62,9 +62,9 @@ const QString C2B_BIBSEARCHER_PDF2TXT_BIN("pdftotext");
 const QString C2B_PDFIMPORT_PDF2TXT_BIN("pdftotext");
 #endif
 #ifdef Q_WS_MACX
-const QString C2B_METADATAPARSER_EXIFTOOL_BIN("c2bExternTools/exiftool");
-const QString C2B_BIBSEARCHER_PDF2TXT_BIN("c2bExternTools/pdftotext");
-const QString C2B_PDFIMPORT_PDF2TXT_BIN("c2bExternTools/pdftotext");
+const QString C2B_METADATAPARSER_EXIFTOOL_BIN("exiftool");
+const QString C2B_BIBSEARCHER_PDF2TXT_BIN("pdftotext");
+const QString C2B_PDFIMPORT_PDF2TXT_BIN("pdftotext");
 #endif
 #ifdef Q_WS_WIN
 const QString C2B_METADATAPARSER_EXIFTOOL_BIN("C:\\Windows\\exiftool.exe");
