@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "metadataParser.h"
@@ -151,7 +151,7 @@ const QString metadataParser::metadata(const QString& fn)
         data = _cbpP->referenceToBibTeX(_ref);
     else
     {
-        const QStringList& bibliographicFields = _cbpP->bibliographicFields();
+        const QStringList& bibliographicFields(_cbpP->bibliographicFields());
         if (_ref.contains("type"))
             data += QString("<%1>%2</%1>\n").arg("type").arg(_ref.value("type"));
         for (int i = 0; i < bibliographicFields.count(); ++i)
