@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "pubmedXml.h"
@@ -68,7 +68,8 @@ void pubmedXml::readAuthors()
     {
         if (name() == "Author" && attributes().value("ValidYN") != "N")
         {
-            QString a;
+            QString a, i;
+            bool abbreviated(true);
             while (reading("Author"))
                 if (name() == "LastName")
                 {
@@ -79,6 +80,7 @@ void pubmedXml::readAuthors()
                 {
                     readNext();
                     a = text().toString() + ' ' + a;
+                    abbreviated = false;
                 }
                 else if (name() == "Suffix")
                 {
@@ -90,7 +92,15 @@ void pubmedXml::readAuthors()
                     else
                         a = a + ' ' + text().toString();
                 }
-            authors.append(a);
+                else if (name() == "Initials")
+                {
+                    readNext();
+                    i = text().toString();
+                }
+            if (abbreviated)
+                authors.append(i + ' ' + a);
+            else
+                authors.append(a);
         }
     }
     _reference["author"] = authors.join(", ");
