@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Modified QRegExp
  *   constans@molspaces.com, 2009
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *
  ***************************************************************************
 ** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
@@ -55,65 +55,82 @@
 #include <new>
 #endif
 
-QT_BEGIN_HEADER
-
-QT_MODULE(Core)
 
 struct EQRegExpPrivate;
 class QStringList;
 
-class Q_CORE_EXPORT EQRegExp
+class EQRegExp
 {
 public:
     enum PatternSyntax { RegExp, Wildcard, FixedString, RegExp2 };
     enum CaretMode { CaretAtZero, CaretAtOffset, CaretWontMatch };
 
     EQRegExp();
-    explicit EQRegExp(const QString &pattern, Qt::CaseSensitivity cs = Qt::CaseSensitive,
-		     PatternSyntax syntax = RegExp);
-    EQRegExp(const EQRegExp &rx);
+    explicit EQRegExp(const QString& pattern, Qt::CaseSensitivity cs = Qt::CaseSensitive,
+                      PatternSyntax syntax = RegExp);
+    EQRegExp(const EQRegExp& rx);
     ~EQRegExp();
-    EQRegExp &operator=(const EQRegExp &rx);
+    EQRegExp& operator=(const EQRegExp& rx);
 
-    bool operator==(const EQRegExp &rx) const;
-    inline bool operator!=(const EQRegExp &rx) const { return !operator==(rx); }
+    bool operator==(const EQRegExp& rx) const;
+    inline bool operator!=(const EQRegExp& rx) const
+    {
+        return !operator==(rx);
+    }
 
     bool isEmpty() const;
     bool isValid() const;
     QString pattern() const;
-    void setPattern(const QString &pattern);
+    void setPattern(const QString& pattern);
     Qt::CaseSensitivity caseSensitivity() const;
     void setCaseSensitivity(Qt::CaseSensitivity cs);
 #ifdef QT3_SUPPORT
-    inline QT3_SUPPORT bool caseSensitive() const { return caseSensitivity() == Qt::CaseSensitive; }
+    inline QT3_SUPPORT bool caseSensitive() const
+    {
+        return caseSensitivity() == Qt::CaseSensitive;
+    }
     inline QT3_SUPPORT void setCaseSensitive(bool sensitive)
-    { setCaseSensitivity(sensitive ? Qt::CaseSensitive : Qt::CaseInsensitive); }
+    {
+        setCaseSensitivity(sensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
+    }
 #endif
     PatternSyntax patternSyntax() const;
     void setPatternSyntax(PatternSyntax syntax);
 #ifdef QT3_SUPPORT
-    inline QT3_SUPPORT bool wildcard() const { return patternSyntax() == Wildcard; }
+    inline QT3_SUPPORT bool wildcard() const
+    {
+        return patternSyntax() == Wildcard;
+    }
     inline QT3_SUPPORT void setWildcard(bool wildcard)
-    { setPatternSyntax(wildcard ? Wildcard : RegExp); }
+    {
+        setPatternSyntax(wildcard ? Wildcard : RegExp);
+    }
 #endif
 
     bool isMinimal() const;
     void setMinimal(bool minimal);
 #ifdef QT3_SUPPORT
-    inline QT3_SUPPORT bool minimal() const { return isMinimal(); }
+    inline QT3_SUPPORT bool minimal() const
+    {
+        return isMinimal();
+    }
 #endif
 
-    bool exactMatch(const QString &str) const;
+    bool exactMatch(const QString& str) const;
 
-    int indexIn(const QString &str, int offset = 0, CaretMode caretMode = CaretAtZero) const;
-    int lastIndexIn(const QString &str, int offset = -1, CaretMode caretMode = CaretAtZero) const;
+    int indexIn(const QString& str, int offset = 0, CaretMode caretMode = CaretAtZero) const;
+    int lastIndexIn(const QString& str, int offset = -1, CaretMode caretMode = CaretAtZero) const;
 #ifdef QT3_SUPPORT
-    inline QT3_SUPPORT int search(const QString &str, int from = 0,
-                                CaretMode caretMode = CaretAtZero) const
-    { return indexIn(str, from, caretMode); }
-    inline QT3_SUPPORT int searchRev(const QString &str, int from = -1,
-                                   CaretMode caretMode = CaretAtZero) const
-    { return lastIndexIn(str, from, caretMode); }
+    inline QT3_SUPPORT int search(const QString& str, int from = 0,
+                                  CaretMode caretMode = CaretAtZero) const
+    {
+        return indexIn(str, from, caretMode);
+    }
+    inline QT3_SUPPORT int searchRev(const QString& str, int from = -1,
+                                     CaretMode caretMode = CaretAtZero) const
+    {
+        return lastIndexIn(str, from, caretMode);
+    }
 #endif
     int matchedLength() const;
 #ifndef QT_NO_REGEXP_CAPTURE
@@ -124,30 +141,28 @@ public:
     QString errorString();
 #endif
 
-    static QString escape(const QString &str);
+    static QString escape(const QString& str);
 
 #ifdef QT3_SUPPORT
-    inline QT3_SUPPORT_CONSTRUCTOR EQRegExp(const QString &pattern, bool cs, bool wildcard = false)
+    inline QT3_SUPPORT_CONSTRUCTOR EQRegExp(const QString& pattern, bool cs, bool wildcard = false)
     {
-        new (this)
-            EQRegExp(pattern, cs ? Qt::CaseSensitive : Qt::CaseInsensitive,
-                    wildcard ? Wildcard : RegExp);
+        new(this)
+        EQRegExp(pattern, cs ? Qt::CaseSensitive : Qt::CaseInsensitive,
+                 wildcard ? Wildcard : RegExp);
     }
 #endif
 
 private:
-    EQRegExpPrivate *priv;
+    EQRegExpPrivate* priv;
 };
 
 Q_DECLARE_TYPEINFO(EQRegExp, Q_MOVABLE_TYPE);
 
 #ifndef QT_NO_DATASTREAM
-Q_CORE_EXPORT QDataStream &operator<<(QDataStream &out, const EQRegExp &regExp);
-Q_CORE_EXPORT QDataStream &operator>>(QDataStream &in, EQRegExp &regExp);
+QDataStream& operator<<(QDataStream& out, const EQRegExp& regExp);
+QDataStream& operator>>(QDataStream& in, EQRegExp& regExp);
 #endif
 
-QT_END_HEADER
-
 #endif // QT_NO_REGEXP
 
 #endif // QREGEXP_H
