@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "settings.h"
@@ -106,21 +106,21 @@ void settings::setDefaults()
 #endif
 #ifdef Q_WS_MACX
     QString C2B_DATA_DIR_MAC(C2B_DATA_DIR);
-    if (QDir(C2B_DATA_DIR + dsep + "data" + dsep).exists())
-        C2B_DATA_DIR_MAC = C2B_DATA_DIR + dsep;
-    else if (QDir(_c2bApp->applicationDirPath() + dsep + "Contents/Resources/data" + dsep).exists())
-        C2B_DATA_DIR_MAC = _c2bApp->applicationDirPath() + dsep + "Contents/Resources" + dsep;
-    defaults["c2bAnnote/AnnoteCssFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + "data/tex2html.css");
+    if (QDir(C2B_DATA_DIR + "/data/").exists())
+        C2B_DATA_DIR_MAC = QDir::cleanPath(C2B_DATA_DIR + '/');
+    else if (QDir(_c2bApp->applicationDirPath() + "/../Resources/data/").exists())
+        C2B_DATA_DIR_MAC = QDir::cleanPath(_c2bApp->applicationDirPath() + "/../Resources/");
+    defaults["c2bAnnote/AnnoteCssFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/tex2html.css");
     defaults["c2bBibSearcher/Pdf2TextBin"] = QDir::cleanPath(C2B_BIBSEARCHER_PDF2TXT_BIN);
-    defaults["c2bPdfImport/LastFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + "testPDFImport/nomeaning1.pdf");
+    defaults["c2bPdfImport/LastFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/testPDFImport/nomeaning1.pdf");
     defaults["c2bPdfImport/Pdf2TextBin"] = QDir::cleanPath(C2B_PDFIMPORT_PDF2TXT_BIN);
-    defaults["cb2Bib/BrowserCssFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + "data/references.css");
+    defaults["cb2Bib/BrowserCssFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/references.css");
     defaults["cb2Bib/ExifToolBin"] = QDir::cleanPath(C2B_METADATAPARSER_EXIFTOOL_BIN);
-    defaults["cb2Bib/JournalFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + "data/abbreviations.txt");
-    defaults["cb2Bib/NetworkFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + "data/netqinf.txt");
-    defaults["cb2Bib/PostprocessBibTeXBin"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + C2B_POSTPROCESS_BIBTEX_BIN);
-    defaults["cb2Bib/PreparserBin"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + "c2btools/ris2bib");
-    defaults["cb2Bib/RegularExpressionFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + dsep + "data/regexps.txt");
+    defaults["cb2Bib/JournalFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/abbreviations.txt");
+    defaults["cb2Bib/NetworkFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/netqinf.txt");
+    defaults["cb2Bib/PostprocessBibTeXBin"] = QDir::cleanPath(C2B_DATA_DIR_MAC + C2B_POSTPROCESS_BIBTEX_BIN);
+    defaults["cb2Bib/PreparserBin"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/c2btools/ris2bib");
+    defaults["cb2Bib/RegularExpressionFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/regexps.txt");
 #endif
 #ifdef Q_WS_WIN
     const QString C2B_APP_DIR(_c2bApp->applicationDirPath() + dsep);
