@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texToHtml.h"
@@ -49,7 +49,8 @@ QString texToHtml::toHtml(const QString& tex)
     _use_relative_links = _settingsP->value("c2bAnnote/UseRelativeLinks").toBool();
     if (_html_filename.isEmpty())
         _use_relative_links = false;
-    _current_dir = QDir(QFileInfo(_html_filename).absolutePath());
+    else
+        _current_dir = QDir(QFileInfo(_html_filename).absolutePath());
 
     parse(tex);
 
@@ -165,7 +166,7 @@ void texToHtml::parseElement(const QString& p, const QString& e, const QString&
     else if (e == "abstract")
         _html += QString("\n<div id=\"abstract\" class=\"abstract\">\n%1\n</div><br /><hr />\n\n").arg(toHtmlString(v.trimmed()));
     else if (e == "verbatim")
-        _html += QString("\n<pre>\n%1\n</pre>\n\n").arg(toHtmlString(v.trimmed(), false));
+        _html += QString("\n<pre>%1</pre>\n\n").arg(v);
     else if (e == "newcommand")
         extractMacro(v);
     else
@@ -314,8 +315,6 @@ void texToHtml::referencesToHtml(QString* reference_list_html)
     keys = ordering.values();
 
     const QString reference_item_html(c2bUtils::fileToString(":/htm/htm/reference_item.html"));
-    const QRegExp initials1("\\b\\w\\b");
-    const QRegExp initials2("[^\\w\\s]");
     const QRegExp nonletters("[^\\w\\s-]");
     QString references;
     for (int i = 0; i < keys.count(); ++i)
