@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterModel.h"
@@ -423,8 +423,7 @@ void c2bCiterModel::_set_sort_indices()
     for (int i = 0; i < _author_count; ++i)
     {
         const int j(_map_author.at(i));
-        _search_string[i] = c2bUtils::toAscii(_author.at(i) + ' ' + _journal.at(j) + ' ' + _year.at(j) + ' ' + _title.at(j),
-                                              c2bUtils::Collation);
+        _search_string[i] = c2bUtils::toAscii(_author.at(i) + ' ' + _journal.at(j) + ' ' + _year.at(j) + ' ' + _title.at(j), c2bUtils::Collation);
     }
     _map_ajyt.resize(_author_count);
     for (int i = 0; i < _author_count; ++i)
@@ -438,8 +437,7 @@ void c2bCiterModel::_set_sort_indices()
     const QString dtt("%1");
     const QChar padding('0');
     for (int i = 0; i < _citation_count; ++i)
-        _search_string[i] = c2bUtils::toAscii(dtt.arg(current_dtt - _included_date.at(i), 10, 10, padding) + ' ' + _title.at(i),
-                                              c2bUtils::Collation);
+        _search_string[i] = c2bUtils::toAscii(dtt.arg(current_dtt - _included_date.at(i), 10, 10, padding) + ' ' + _title.at(i), c2bUtils::Collation);
     _map_it.resize(_citation_count);
     for (int i = 0; i < _citation_count; ++i)
         _map_it[i] = i;
@@ -466,8 +464,7 @@ void c2bCiterModel::_set_sort_indices()
 
     // YAJT
     for (int i = 0; i < _citation_count; ++i)
-        _search_string[i] = c2bUtils::toAscii(_year.at(i) + ' ' + _author_string.at(i) + ' ' + _journal.at(i) + ' ' + _title.at(i),
-                                              c2bUtils::Collation);
+        _search_string[i] = c2bUtils::toAscii(_year.at(i) + ' ' + _author_string.at(i) + ' ' + _journal.at(i) + ' ' + _title.at(i), c2bUtils::Collation);
     _map_yajt.resize(_citation_count);
     for (int i = 0; i < _citation_count; ++i)
         _map_yajt[i] = i;
