@@ -1,11 +1,11 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bClipboard.h"
-#ifdef CB_POLL
+#ifdef C2B_USE_CBPOLL
 #include "clipboardPoll.h"
 #endif
 
@@ -24,21 +24,20 @@ c2bClipboard::c2bClipboard(QObject* parento) : QObject(parento)
 
     // Setting timer
     _interval = 1000;
-    // Uncomment the 4 timer-related lines if clipboard appears unresponsive
-    // and it cannot be compiled with cbpoll option
-    _timer = 0;
-//    _timer = new QTimer(this);
-//    connect(_timer, SIGNAL(timeout()), this, SLOT(checkData()));
-
-#ifdef CB_POLL
+#ifdef C2B_USE_CBPOLL
     _poll = new clipboardPoll();
     connect(_poll, SIGNAL(clipboardChanged(bool)), this, SLOT(newClipboardData(bool)));
+#else
+#ifdef Q_WS_X11
+    _timer = new QTimer(this);
+    connect(_timer, SIGNAL(timeout()), this, SLOT(checkData()));
+#endif
 #endif
 }
 
 c2bClipboard::~c2bClipboard()
 {
-#ifdef CB_POLL
+#ifdef C2B_USE_CBPOLL
     delete _poll;
 #endif
 }
@@ -94,17 +93,23 @@ void c2bClipboard::setConnected(bool zconn)
             _cbs_text = _cb->text(QClipboard::Selection);
             connect(_cb, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
         }
-#ifdef CB_POLL
+#ifdef C2B_USE_CBPOLL
         _poll->startT(_interval);
+#else
+#ifdef Q_WS_X11
+        _timer->start(_interval);
+#endif
 #endif
-//        _timer->start(_interval);
     }
     else
     {
-#ifdef CB_POLL
+#ifdef C2B_USE_CBPOLL
         _poll->stopT();
+#else
+#ifdef Q_WS_X11
+        _timer->stop();
+#endif
 #endif
-//        _timer->stop();
         disconnect(_cb, SIGNAL(dataChanged()), this, SLOT(dataChanged()));
         if (_supports_selection)
             disconnect(_cb, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
