@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCLIPBOARD_H
@@ -21,7 +21,7 @@
     @author Pere Constans
 */
 
-#ifdef CB_POLL
+#ifdef C2B_USE_CBPOLL
 class clipboardPoll;
 #endif
 
@@ -44,12 +44,15 @@ private:
     QClipboard* _cb;
     QString _cb_text;
     QString _cbs_text;
-    QTimer* _timer;
     bool _is_connected;
     bool _supports_selection;
     uint _interval;
-#ifdef CB_POLL
+#ifdef C2B_USE_CBPOLL
     clipboardPoll* _poll;
+#else
+#ifdef Q_WS_X11
+    QTimer* _timer;
+#endif
 #endif
 
 
