@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPdfImport.h"
@@ -215,6 +215,31 @@
     algorithms may drop author middle names if a given author has 'too many
     names'. Expect convenience over accuracy on other sources.
 
+    - <b>Can I use cb2Bib to extract comma separated value CSV references?</b>
+    Yes. To automatically import multiple CSV references you will need one
+    regular expression. If you can control CSV export, choose | as separator,
+    since comma might be used, for instance, in titles. The regular expression
+    for
+  \verbatim
+  AuthName1, AuthName2 | Title | 2010
+  \endverbatim
+    will simply be
+  \verbatim
+  author title year
+  ^([^|]*)\|([^|]*)\|([^|]*)$
+  \endverbatim
+    The reference file <tt>references.csv</tt> can then be split to single-line
+    files typing
+  \verbatim
+  split -l 1 references.csv slineref
+  \endverbatim
+    and the command
+  \verbatim
+  cb2bib --txt2bib slineref* references.bib
+  rm -f slineref*
+  \endverbatim
+  will convert <tt>references.csv</tt> to BibTeX file <tt>references.bib</tt>
+
     <p>&nbsp;</p>
 */
 c2bPdfImport::c2bPdfImport(QWidget* parentw) : QDialog(parentw)
