@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
@@ -16,6 +16,7 @@
 #include <document.h>
 #include <settings.h>
 
+#include <QCoreApplication>
 #include <QTextStream>
 
 
@@ -50,6 +51,7 @@ int c2bTests::allTests()
     heuristic_author();
     heuristic_check_patterns();
     compression_check();
+    write_information();
 #endif
     cout << endl << endl;
     cout << "Tests done. Tests: " << _test_count << " Failed: " << _failed_test_count << endl;
@@ -105,6 +107,42 @@ void c2bTests::compression_check()
     ++_test_count;
 }
 
+void c2bTests::write_information()
+{
+    cout << endl;
+    cout << "-------------------------" << endl;
+    cout << "Miscellaneous information" << endl;
+    cout << "-------------------------" << endl;
+    cout << endl;
+    cout << "Version: cb2bib " << C2B_VERSION << endl;
+#if C2B_USE_LZO
+    cout << "Compression: lzo2" << endl;
+#else
+    cout << "Compression: zlib" << endl;
+#endif
+#if C2B_USE_WEBKIT
+    cout << "Compiled against QtWebKit: yes" << endl;
+#else
+    cout << "Compiled against QtWebKit: no" << endl;
+#endif
+#if C2B_USE_CBPOLL
+    cout << "Clipboard polling: yes" << endl;
+#else
+    cout << "Clipboard polling: no" << endl;
+#endif
+    cout << "Application binary path: " << QCoreApplication::instance()->applicationDirPath() << endl;
+    cout << "Application hardcoded data path: " << C2B_DATA_DIR << endl;
+#ifdef Q_WS_MACX
+    QString C2B_DATA_DIR_MAC(C2B_DATA_DIR);
+    if (QDir(C2B_DATA_DIR + "/data/").exists())
+        C2B_DATA_DIR_MAC = QDir::cleanPath(C2B_DATA_DIR + '/');
+    else if (QDir(QCoreApplication::instance()->applicationDirPath() + "/../Resources/data/").exists())
+        C2B_DATA_DIR_MAC = QDir::cleanPath(QCoreApplication::instance()->applicationDirPath() + "/../Resources/");
+    cout << "Application macosx data path: " << C2B_DATA_DIR_MAC << endl;
+#endif
+    cout << endl;
+}
+
 void c2bTests::heuristic_author()
 {
     cout << endl;
@@ -498,6 +536,14 @@ void c2bTests::author_parser()
     input = "VICTOR Yu. DMITRI,3 ANDRIY KARPOFF";
     check_test(author == bp.parse("author", input), input, author);
 
+    author = "Yu. Dmitri and A. Karpoff";
+    input = "Yu. Dmitri,3 Andriy Karpoff";
+    check_test(author == bp.parse("author", input), input, author);
+    input = "Yu. DMITRI,3 ANDRIY KARPOFF";
+    check_test(author == bp.parse("author", input), input, author);
+    input = "YU. DMITRI,3 ANDRIY KARPOFF";
+    check_test(author == bp.parse("author", input), input, author);
+
     cout << "From medline:" << endl;
     author = "C. L. Maggi III";
     input = "Maggi, Carla L., III";
