@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "cb2Bib.h"
@@ -47,7 +47,6 @@
     detailed list of changes and acknowledgments, and \ref relnotes for
     additional notes and information.)
 
-    See also \ref relnotes140.
 
 <p>&nbsp;</p>
 
@@ -336,7 +335,7 @@
 
     - Qt 4.4.0 or higher from
     \htmlonly
-    <a href="http://www.qtsoftware.com/downloads" target="_blank">Trolltech</a>.
+    <a href="http://qt.nokia.com/downloads" target="_blank">Qt Nokia</a>.
     \endhtmlonly
     On a Linux platform with Qt preinstalled, make sure that the <tt>devel</tt>
     packages and Qt tools are also present.
@@ -408,7 +407,7 @@
 
     <p>&nbsp;</p>
 
-    <em>The <b>cb2Bib</b>, Pere Constans, Copyright &copy; 2004-2010.\n
+    <em>The <b>cb2Bib</b>, Pere Constans, Copyright &copy; 2004-2011.\n
     First released, version 0.1.0 on 2004-06-29. \n
     GET_UPDATEDON</em>
 */
@@ -1076,7 +1075,7 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
     addAction(ui.editRegExpsAction);
     c2bUtils::addSeparator(this);
     addAction(ui.openAnnoteAction);
-#ifndef C2B_WEBKIT
+#ifndef C2B_USE_WEBKIT
     ui.openAnnoteAction->setDisabled(true);
 #endif
     c2bUtils::addSeparator(this);
@@ -1248,7 +1247,7 @@ void cb2Bib::on_viewAboutB_clicked()
                 "</td></tr></tbody>"
                 "</table>"
                 "<br /> %2 <br />"
-                "<p align=\"center\">Copyright (C) 2004-2010 by Pere Constans<br />"
+                "<p align=\"center\">Copyright (C) 2004-2011 by Pere Constans<br />"
                 "<a href=\"http://www.molspaces.com/cb2bib/index.html\">"
                 "http://www.molspaces.com/cb2bib</a></p>&nbsp;"
                 "<p align=\"center\"><i>The cb2Bib is licensed under the terms of the "
