@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2010 by Pere Constans
+ *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.4. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "qtsingleapplication/src/qtsingleapplication.h"
@@ -12,7 +12,7 @@
 #include "c2bSettings.h"
 #include "cb2Bib.h"
 
-#ifdef C2B_WEBKIT
+#ifdef C2B_USE_WEBKIT
 #include "c2bAnnote.h"
 #ifdef C2B_STATIC_LINKING
 #include <QtPlugin>
@@ -97,7 +97,7 @@ int main(int argc, char* argv[])
             }
             else if (c2b_settings->cl_view_annote)
             {
-#ifdef C2B_WEBKIT
+#ifdef C2B_USE_WEBKIT
                 c2bAnnote c2B;
                 if (c2B.show())
                     code = app.exec();
